@@ -173,13 +173,11 @@ sub _make_clause_case_insensitive {
     my $value    = shift;
 
     if ( $self->_case_insensitivity_valid( $column, $operator, $value ) ) {
-        if ( $operator =~ /(?:LIKE|=|IN)/i ) {
-            $column = "LOWER($column)";
-            if ( $operator =~ /^(IN|=)$/i and ref($value) eq 'ARRAY' ) {
-                $value = [ map {"LOWER($_)"} @$value ];
-            } else {
-                $value = "LOWER($value)";
-            }
+        $column = "LOWER($column)";
+        if ( $operator =~ /^(IN|=)$/i and ref($value) eq 'ARRAY' ) {
+            $value = [ map {"LOWER($_)"} @$value ];
+        } else {
+            $value = "LOWER($value)";
         }
     }
     return ( $column, $operator, $value );
